#
# spec file for package icecream
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           icecream
Version:        1.4.0
Release:        2.6
Summary:        Distributed Compilation in the Network
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Tools/Building
URL:            https://github.com/icecc/icecream
Source0:        https://github.com/icecc/icecream/releases/download/1.4/icecc-%{version}.tar.xz
Source1:        iceccd.xml
Source2:        iceccd.service.in
Source3:        iceccd-wrapper
Source4:        icecc-scheduler.xml
Source5:        icecc-scheduler.service.in
Source6:        icecc-scheduler-wrapper
Source7:        icecream-tmpfiles.conf
Source8:        sysconfig.icecream
BuildRequires:  clang-devel
BuildRequires:  docbook2x
BuildRequires:  firewall-macros
BuildRequires:  gcc-c++
BuildRequires:  libarchive-devel
BuildRequires:  libcap-ng-devel
BuildRequires:  libtool
BuildRequires:  libxslt-tools
BuildRequires:  libzstd-devel
BuildRequires:  lzo-devel
BuildRequires:  systemd-rpm-macros
Requires:       %{_bindir}/bzip2
Requires:       /bin/tar
Requires:       logrotate
Requires(pre):  %fillup_prereq
Requires(pre):  %{_sbindir}/groupadd
Requires(pre):  %{_sbindir}/useradd
%{?systemd_requires}
Recommends:     gcc-c++

%description
Distributed compiler with a central scheduler to share build load.

%package -n libicecream-devel
Summary:        For Distributed Compile in the Network
Group:          Development/Tools/Building
Requires:       libarchive-devel
Requires:       libcap-ng-devel
Requires:       libstdc++-devel
Requires:       libzstd-devel
Requires:       lzo-devel

%description -n libicecream-devel
icecream is the next generation distcc.

%package -n icecream-clang-wrappers
Summary:        Distributed Compile Wrappers for Clang
Group:          Development/Tools/Building
Requires:       clang
Requires:       icecream
Supplements:    (icecream and clang)

%description -n icecream-clang-wrappers
Wrapper symlinks for clang/clang++ for icecream distributed building.

%prep
%setup -q -n icecc-%{version}
cp %{SOURCE8} suse/
# DO NOT ADD PATCHES without github reference

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
autoreconf -fiv
%configure \
  --enable-clang-rewrite-includes \
  --enable-clang-wrappers \
  --libexecdir %{_libexecdir}
make %{?_smp_mflags} V=1

%install
%make_install templatesdir=%{_fillupdir}
# firewalld instead of SuSEfirewall2
rm -R %{buildroot}/%{_sysconfdir}/sysconfig/SuSEfirewall2.d
install -m644 -p -D %{SOURCE1} %{buildroot}%{_prefix}/lib/firewalld/services/iceccd.xml
install -m644 -p -D %{SOURCE4} %{buildroot}%{_prefix}/lib/firewalld/services/icecc-scheduler.xml
# unit files and wrappers
sed -e 's#@LIBEXECDIR@#%{_libexecdir}#' < %{SOURCE2} > iceccd.service
install -m644 -p -D iceccd.service %{buildroot}%{_unitdir}/iceccd.service
install -m755 -p -D %{SOURCE3} %{buildroot}%{_libexecdir}/icecc/iceccd-wrapper
sed -e 's#@LIBEXECDIR@#%{_libexecdir}#' < %{SOURCE5} > icecc-scheduler.service
install -m644 -p -D icecc-scheduler.service %{buildroot}%{_unitdir}/icecc-scheduler.service
install -m755 -p -D %{SOURCE6} %{buildroot}%{_libexecdir}/icecc/icecc-scheduler-wrapper
# make sure runtime directories are automatically created
install -m644 -p -D %{SOURCE7} %{buildroot}/%{_tmpfilesdir}/icecream.conf
# cleanup SysV init
rm %{buildroot}/%{_sysconfdir}/init.d/icecream
rm %{buildroot}/%{_sbindir}/rcicecream
ln -s service %{buildroot}/%{_sbindir}/rciceccd
ln -s service %{buildroot}/%{_sbindir}/rcicecc-scheduler
sed -i -e '1s@/usr/bin/env bash@/bin/bash@'  %{buildroot}/%{_bindir}/icecc-create-env

%preun
%service_del_preun iceccd.service icecc-scheduler.service

%pre
%{_sbindir}/groupadd -r icecream 2> /dev/null || :
%{_sbindir}/useradd -r -g icecream -s /bin/false -c "Icecream Daemon" -d %{_localstatedir}/cache/icecream icecream 2> /dev/null || :
%service_add_pre iceccd.service icecc-scheduler.service
# save state of old icecream SysV service
if [ "$1" -gt 1 ]; then
  /usr/sbin/systemd-sysv-convert --save icecream || :
fi

%post
%if 0%{?suse_version}
%fillup_only
%endif
%tmpfiles_create %_tmpfilesdir/icecream.conf
%firewalld_reload
# migrate runlevel settings
if [ "$1" -gt 1 ] && [ -e /var/lib/systemd/sysv-convert/database ] ; then
    grep -q 'ICECREAM_RUN_SCHEDULER="yes"' %{_sysconfdir}/sysconfig/icecream &&
        sed -i -e '/icecream\s/ p; s/icecream\s/icecc-scheduler /' /var/lib/systemd/sysv-convert/database
    sed -i -e '/icecream\s/ s/icecream\s/iceccd /' /var/lib/systemd/sysv-convert/database
fi
%service_add_post iceccd.service icecc-scheduler.service
# restart services
if [ "$1" -gt 1 ] ; then
    if systemctl -q is-active icecream ; then
        systemctl stop icecream
        systemctl start iceccd
        systemctl -q is-enabled icecc-scheduler && systemctl start icecc-scheduler
    fi
fi

%postun
%service_del_postun iceccd.service icecc-scheduler.service

%files
%doc README.md NEWS
%license COPYING
%config %{_sysconfdir}/logrotate.d/icecream
%{_bindir}/icecc-create-env
%{_bindir}/icecc-test-env
%{_bindir}/icecc
%{_bindir}/icerun
%{_sbindir}/icecc-scheduler
%{_sbindir}/iceccd
%{_sbindir}/rcicecc*
%{_mandir}/man*/*
%{_libexecdir}/icecc
%exclude %{_libexecdir}/icecc/bin/clang
%exclude %{_libexecdir}/icecc/bin/clang++
%dir %{_prefix}/lib/firewalld/
%dir %{_prefix}/lib/firewalld/services/
%{_prefix}/lib/firewalld/services/icecc*.xml
%{_unitdir}/icecc*.service
%{_tmpfilesdir}/icecream.conf
%if 0%{?suse_version}
%{_fillupdir}/sysconfig.icecream
%endif
%attr(-,icecream,icecream) %{_localstatedir}/cache/icecream
%attr(-,icecream,icecream) %{_localstatedir}/log/icecream
%ghost /run/icecc

%files -n libicecream-devel
%{_includedir}/icecc
%{_libdir}/libicecc.*
%{_libdir}/pkgconfig/icecc.pc

%files -n icecream-clang-wrappers
%{_libexecdir}/icecc/bin/clang
%{_libexecdir}/icecc/bin/clang++

%changelog
* Mon May 30 2022 Lubos Lunak <l.lunak@centrum.cz>
- Do not start iceccd with verbose options.
* Fri Mar  4 2022 Stephan Kulow <coolo@suse.com>
- Update to 1.4
  - scheduler assigns jobs with larger priority first, so compilations with higher 'nice' value
    do not interfere with normal compilations
  - avoid large timeouts if there is a network problem
  - support for -march/-mcpu/-mtune used with =native (proper specific flags will be substituted)
  - support for Clang's -fmodules, by removing the -fmodules flag for remote compilation
  - do not keep host lock when sending preprocessed source (reduces chance of network timeouts)
  - send more jobs in advance to nodes with many CPU cores
  - try to use larger network buffers
  - force local compilations if --coverage is used
  - correctly clean up caches
  - handle properly the case when something removes files in the cache directory
* Wed Sep 22 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * icecc-scheduler.service.in
  * iceccd.service.in
* Sun Jan 10 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use the correct paths in systemd unit files for wrappers
  installed in libexecdir.
- Cleanup spec file
* Thu Aug 27 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Install firewalld sercice files to %%{_prefix}/lib/firewalld, NOT
  %%{_libexecdir}/firewalld (boo#1174075).
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.3.1
  get rid of the ASAN travis build
  Revert icecc-create-env darwin optimization
* Tue Sep 17 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Mon Sep 16 2019 Stephan Kulow <coolo@suse.com>
- Fix source URL
* Thu Sep 12 2019 Lubos Lunak <l.lunak@centrum.cz>
- update to 1.3
  - remove hardcoded compiler paths (compiler tarball is created with the same compiler that is used for build)
  - avoid build overloading by limiting number of local preprocessing runs to local CPUs available
  - fix Objective C/C++ support
  - fix job preloading to again allow sending one extra job to a fully busy node
  - use libarchive to handle archives instead of using tar
  - support xz and zstd compression for compiler tarballs (improved speed/size)
  - use zstd compression when sending network data, if possible (improved speed)
  - improve speed of creating compiler tarballs
  - more robust handling of receiving compiler tarballs
  - default cache size for compiler environments has been increased to 256MiB
  - path handling fixes
  - platforms improvements in icecc-create-env
  - fix memory detection on MacOSX
  - improve local performance when -include-pch is used
  - simplify PCH handling
  - fix keeping order of compiler debug arguments, especially -gsplit-dwarf
  - better support for assembler and preprocessor flags when building the Linux kernel
  - force local rebuild if local preprocessing fails (works around some GCC -fdirectives-only problems)
  - limit -fdirectives-only workarounds only to cases when it is used
  - improved handling of network timeouts
  - avoid a timeout when the scheduler cannot find any suitable host for building
  - if ICECC_SLOW_NETWORK=1 is set, sending network data is split into smaller chunks
  - --interface option allows restricting which network interface daemons will use
  - improved debug logs
  - release builds are built without assert checks, use --enable-debug for developer builds
  - added a manual page for icerun
- fix scheduler warning about missing user icecream
* Sun Sep  8 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use FAT LTO objects in order to provide proper static library.
- Add missing lzo-devel Requires in libicecream-devel.
* Wed Jan  9 2019 bwiedemann@suse.com
- Use icecream user+group instead of nonexistent icecc
  in scheduler (boo#1121250)
* Fri Nov 30 2018 Stephan Kulow <coolo@suse.com>
- update to 1.2
  - Add more compiler flags to the list that mean build locally
  * -pedantic (preprocessing only)
  * -pedantic-errors (preprocessing only)
  * -fsyntax-only
  - don't force local compile on -include-pch
  - Make load calculation better
  - Limit amount of data sent at one time for slow networks/remotes
  - Many updates to the tests
  - Better logs of some error conditions
  - Build locally if it is likely that there will not be more compiles
  - Support adding gcc and clang to the same environment
  - Better handling of icerun
  - Cygwin now works as a client
  - Don't expose Host endianness to network
  - General code cleanup
* Fri Jun 29 2018 stefan.bruens@rwth-aachen.de
- Add firewalld rules, remove SuSEFirewall2 config
- Add systemd service units for icecream, icecream-scheduler
- Create socket and environment directories using tmpfiles.d
- Strip no longer needed options from config file
- Spec file cleanup:
  - remove cruft for 12.2 and older
  - use %%license tag
* Wed Jan  3 2018 mpluskal@suse.com
- Update dependencies to fix building on SLE
- Cleanup spec file:
  * Run spec-clener
  * Make building more verbose
* Wed Jan  3 2018 jolz@gmx.de
- changes icecream 1.1rc3 -> 1.1
  - revert "Add load control for preprocessing"
  - better handle clang arugments with spaces
  - remove "crashme" command from scheduler
  - better logging around exception 30
- changes icecream 1.1rc2 -> 1.1rc3
  - Fix broken pipe race condition
  - Better error handling
  - Crash fixes
  - Documentation update
  - Include objcopy in environment if it exists
  - Add CI builds on travis-ci: OSX, ubuntu trusty
  - Fixed several memory errors
  - Extract enviornments with compile priority, not daemon priority
  - Handle spaces in the parameters following -MT
  - Handle -target -arch -c-isystem and -cxx-isystem (clang)
  - Handle NAT situations better
  - Add load control for preprocessing
  - Handle scheduler unable to reach remote machine
  - Make scheduler election algorithm handle multiple netnames
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Tue May 30 2017 coolo@suse.com
- update to 1.1rc2
  - -gsplit-dwarf support for debug fission (https://gcc.gnu.org/wiki/DebugFission)
  - bug fixes since 1.1rc1
- switch to github tar - and related build system changes
* Fri Oct 31 2014 coolo@suse.com
- update to 1.1rc1 (including bsc#861524 and CVE-2014-4607)
  - require capng
  - allow ICECC_VERSION file to start with a .
  - work with different executable names for docbook-to-man on different distributions
  - support color diagnostics if possible
  - fix several crashes
  - clean up and improve documentation
  - move icecc-create-env to bindir.
  - Try to use only the best available scheduler
  - make daemon port configurable
  - USE_SCHEDULER now accepts host:port to change ports
  - use system lzo, drop bundled minilzo
  - force local compilation when required in more cases
  - detect some clang out of memory errors.
  - better support for FreeBSD
  - bump protocol version to 34
  - daemon requires chroot
  - some code refactoring for better maintainability
  - find if feature is supported by checking protocol version
  - better logging on error conditions
  - Create many tests cases
  - use path name instead of localhost for unix socket
  - clean up build system
  - use getnameinfo() instead of inet_ntoa()
  - fix some valgrind found issues
  - drop supplementary groups before setgid()
  - make signal handlers more robust
  - work better if user "icecc" does not exist
  - find compilers outside of PATH when building locally
- remove upstream patches
  0001-handle-HOME-not-being-set.patch
  0002-icecc-fix_s390_build.patch
-  make gcc-c++ only a Recommends: in the spec file
    A machine running only the daemon actually does not need any compiler.
* Wed Feb 12 2014 ro@suse.de
- 0002-icecc-fix_s390_build.patch:
  fix build for s390/s390x
* Tue Jul 16 2013 llunak@suse.com
- handle $HOME not being set:
  0001-handle-HOME-not-being-set.patch
* Sat Jun 29 2013 llunak@suse.com
- update to 1.0.1
  - use su option for logrotate
  - require logrotate for suse package
  - Remove filenames from md5sum output
  - Fix off-by-one error
  - add missing cap-ng.m4
  - uninstall also SUSE-specific files when uninstalling
  - install COPYING, README.md and NEWS as useful user documentation
  - use m4/ and ship cap-ng.m4 there
  - if -lcap-ng is needed for icecc.a, add it to .pc file (for icemon)
  - libicecream-devel may require libcap-ng-devel
  - fix icecc-create-env with clang 3.3+
  - fix /var/run/icecc handling
  - make sure to not hide e.g. SEGV from a tool with exit code 0
  - detect bad_alloc as out-of-memory
  - add "[Cc]annot allocate memory" to the list of OOM error messages
  - Detect gcc "out of memory allocating" as EXIT_OUT_OF_MEMORY. Closes #49
  - Avoid symlinks in the absolute paths
  - swap arguments for kill() call, since pid is the first argument
- remove fix-startup.patch, cap-ng-link.patch
* Thu Jun 27 2013 llunak@suse.com
- avoid crash on first launch after reboot (bnc#827118):
  fix-startup.patch
* Mon Apr  8 2013 llunak@suse.com
- include -lcap-ng in pkgconfig file if needed, for icemon:
  cap-ng-link.patch
* Thu Apr  4 2013 llunak@suse.com
- update to 1.0.0 (final)
  - log error message when cleaning up cache fails during startup
  - if getuid() != 0, then our u/gid will be getu/gid() the whole time
  - chmod/chown envs dir when preparing this
  - be more careful when cleaning up envs directory
  - cleanup envs dir still with root privileges
  - mkdir -p
  - Revert "cleanup envs dir still with root privileges"
  - cleanup envs dir in %%post in specfile
  - fix scheduler binary name in suse specfile
  - with cap-ng geteuid() is not a sign of being able to do chroot
  - avoid debug message without endl
  - avoid unused parameter warnings
  - install clang/clang++ wrappers symlinks conditionally again
  - adjust specfile for optional clang symlinks
  - make clang wrappers package also require clang
  - fix clang wrappers build
  - refer to icecream-users@googlegroups.com ML as the contact
  - mention the Linux3_ hack leading to nodes sometimes not being used
  - Linux3_ nodes may not compile on other nodes either, actually
  - prevent icerun-wrapped commands failing if path contains 'clang'
  - remove unnecessary references to KDE to make icecream look KDE-specific
  - adjust references to icecream path
  - sync the ccache section between README.md and the manpage
  - AC_CONFIG_HEADERS instead of obsolete and removed AM_CONFIG_HEADER
  - add the README.md to the tar
  - mild relicensing, the code taken from ksysguardd is really a minor part by now
* Tue Jan 29 2013 dmueller@suse.com
- install COPYING, README.md and NEWS as useful user documentation
* Wed Jan  9 2013 coolo@suse.com
- update to 0.9.98.3 (1.0rc5)
  - fix cap_ng support
  - chmod/chown envs dir when preparing this
  - be more careful when cleaning up envs directory
  - cleanup envs dir in %%post in specfile
  - install clang/clang++ wrappers symlinks conditionally again
  - add the README.md to the tar
  - mild relicensing, the code taken from ksysguardd is really a minor part by now
* Sun Jan  6 2013 coolo@suse.com
- update to 0.9.98.2 (1.0rc4)
  - suse: Backports from OBS and create symlinks in /opt/icecream/bin on openSUSE <= 12.2.
  - fix libexec dir name in opensuse specfile
  - icecream doesn't use m4 directory
  - explicit configure option for whether to use clang's include rewriting
  - use the clang rewrite options in opensuse specfile
  - fix builddir != srcdir
  - icecream user on suse is 'icecream', not 'icecc'
  - do not remove env. basedir itself
  - do not chown() with root uid
  - do not complain needlessly about missing icecc user
  - Fix icecc-create-env for relative paths
  - Use docbook2man to generate manpages rather than KDE calls.
* Wed Dec 26 2012 coolo@suse.com
- update to 0.9.98.1 (1.0rc3)
  - install icecc links in a more convenient dir
  - fix for assembler usage during kvm builds
  - fix generation of man pages
  - some readme generated from en.opensuse.org content
  - update autoconf and automake macros
  - install clang++ clang symlinks unconditionally.
  - move openSUSE's rpm install scripts to suse/Makefile.am.
  - links installation should be pkglibexec instead of libexec
  - rename scheduler to icecc-scheduler to avoid name clash
  - change to an unprivileged user when running the scheduler as root.
  - move scheduler logs to icecc specific dir
  - ignore if meinproc is not avilable
  - version bump minilzo to 2.0.6.
* Tue Dec 18 2012 coolo@suse.com
- update to 0.9.97 (1.0rc1)
  - support for Clang compiler
  Clang now should work out of the box just like GCC.
  Clang with -frewrite-includes option is recommended (3.2+ or patched).
  - support 'icecc <compilername>' properly
  - try to avoid compiling on the local machine if it is busy
  - do not use old compiler if it was changed while icecream daemon was running
  - verify if remote hosts can actually be used for compilation (avoids
  problems with old kernel versions)
  - support for custom compiler plugins (GCC/Clang)
  - fix gcc 4.6 support
  - reduce usage of PATH_MAX for better portability
  - fix build-native to add default GNU assembler
  - fix SIGSEGV calling build_native without args
  - parse @file option
  - skip .[h,hpp] header files and check precompiled headers from -include opts
  - move log and socket to an icecc especific folder
  - rename nobody to user
  - add support for libcap-ng
  - moving to https://github.com/icecc/icecream
  - add clang wrapper symlinks
  - allow normal users to actually connect to the daemon's unix socket
  - rebuild environment if the compiler changes
  - check if the remote node can actually use an environment
  - setting to avoid using hosts where the environment cannot be checked
  - add [compiler] to the command line template in --help
  - support for compiler plugins / multiple native environments
  - do not create environments containing both gcc and clang
  - check env cache size also when creating new native environment
  - keep native envs longer only if there aren't too many
  - no "basic" native env really anymore, now with env per each compiler
  - include paths in tarball md5sum
  - do not use gcc when creating env.tarball for clang
  - force env. tarball regeneration if it doesn't exist
  - fix for assembler usage during kvm builds
* Wed Sep 12 2012 ro@suse.de
- prevent endless loop in last change
* Fri Sep  7 2012 dmueller@suse.com
- fallback to local build for some building BIOS (bnc#778924)
* Sun Jul 22 2012 aj@suse.de
- Add icecream-include.patch: missing sys/resource include (glibc 2.16)
* Thu Mar 22 2012 dmueller@suse.de
- make linux 3 based kernel hosts incompatible with the rest, just
  as a workaround for glibc becoming incompatble
* Thu May 19 2011 coolo@novell.com
- update to 0.9.7
  - bug fix for -MD and -MF
  - bug fix for gcc 4.6 plugins
* Tue Aug  3 2010 coolo@novell.com
- Update to 0.9.6
  - fix installation issues
  - add a value type of ticks in /proc - and make it long long
  - fix kFreeBSD build
  - fix run-failure with glibc 2.11
  - allow tgz as extension
  - support more local args (bnc#625621)
* Thu May 27 2010 dmueller@suse.de
- fix build against glibc 2.11
* Mon Feb  1 2010 coolo@novell.com
- Update to 0.9.5
  - fix: close the file descriptor (novell bug bnc#525799)
  - log PID even if no prefix is specified
  - allow get_msg() to fetch data from the kernel even if timeout is 0.
  - clean up event loop of gcc invocation
  - Install an "icerun" symlink that will serialize commands through
  icecream's local daemon
* Thu Apr 30 2009 coolo@suse.de
- Update to 0.9.4
  - don't leak file descriptor to create-env
  - don't use the shell to call simple commands
  - make a special exception for - in rest args (bnc#495786)
  - Fix way icecream changes permissions of /var/cache/icecream
* Sun Feb 15 2009 coolo@suse.de
- update to 0.9.3 to fix compilation with gcc 4.4
* Sun Nov  2 2008 coolo@suse.de
- update to 0.9.2 to include patches upstreamed
  - Add accessor for the hostname of the scheduler, so that we can
  show it in a tooltip in icemon in the future.
  - Only localize job if we find -Wa,.*-a[a-z]*= in an argument
  - also add accessor for network name
  - if called as "icecc" (i.e., not through a symlink) and the first
  argument starts with a slash, use that as the command to run.
* Mon Oct  6 2008 dmueller@suse.de
- correct service description (bnc#424431)
* Fri Aug 22 2008 aj@suse.de
- Fix init script.
* Thu Jun 19 2008 coolo@suse.de
- update to 0.9.1
  - trying to support gentoo x86_64
  - -mcpu=native has to compile locally (gentoo bug 183586#c13)
  - don't compile C files with C++ compile if ICECC_CXX is set
* Mon May 12 2008 coolo@suse.de
- update to 0.9.0 (no functionial change in suse package):
  * merged make-it-cool-branch
* Fri May  9 2008 dmueller@suse.de
- update make-it-cool-branch:
  * fix handling of pch's
  * ignore really small environments
  * small code cleanups and portability fixes
* Thu Apr 10 2008 coolo@suse.de
- fix compilation with glibc 2.8
* Tue Feb 12 2008 dmueller@suse.de
- more robustness fixes
* Fri Feb  8 2008 dmueller@suse.de
- fix scheduler "crash"
- fix scheduler to not bring down network of the machine during a
  DoS attack from a broken compile daemon
* Mon Jan 28 2008 dmueller@suse.de
- fix pid file generation in the daemon
* Tue Jan 15 2008 dmueller@suse.de
- update to current make-it-cool branch:
  * small bugfixes
* Thu Nov  8 2007 ro@suse.de
- install sysconfig fillup template also for <= 10.2
  (used unconditionally in rc-script)
* Thu Aug  2 2007 dmueller@suse.de
- update make-it-cool branch diff for the following changes:
  * fix handling of control channels, implement idle-timeout
  * make the protocol more rebust against integer overflows
    and other attacks
  * fix icecream update not restarting the daemon
  * clean up scheduler code to remove unnecessary dynamic_casts
  * improve error handling for protocol errors on daemon<->scheduler
    communication
  * daemon will no longer flood scheduler with connection requests
    when he got kicked
  * monitor connections are more bulky now and use much smaller
    messages to reduce network overhead
  * client will now try to fetch the error message from the compile
    server before claiming that the compile server unexpectedly ended
    connection.
  * Job statistics in the monitor were all broken. Fixed.
* Thu Jul 26 2007 dmueller@suse.de
- update make-it-cool branch diff to workaround scheduler hanging
  when icecream monitors are connected
- fix double deletion in the scheduler
- switch control connections to bulk mode
- remove errnous error in client when local daemon is offline
- implement host blocking
* Wed Jul 18 2007 dmueller@suse.de
- 0.8.0:
  - write a pid file. patch by Ismail Doenmez
  - precompiled header support, needed for compiling Qt 4.3
  - add support for --no-remote. patch by Matt Gruenke
  - update node name each time we login to the scheduler.
  - treat -combine and -fdump* as always local
  - Merged make-it-cool branch:
  * implement job preloading
  * asynchronous install of new environments
  * uses tcp keepalive for network connection tracking
- added make-it-cool branch diff:
  * implement local scheduling of arbitrary build commands
    (e.g. meinproc)
  * add non-blocking connect to the scheduler to improve latency
* Mon Apr 23 2007 coolo@suse.de
- provide SUSEfirewall descriptions (#247340)
* Wed Sep 13 2006 coolo@suse.de
- 0.7.14:
  - fix current_kids getting out of sync if send_scheduler
    failes in an unfortunate moment
  - fix reporting the error
  - add more to the internals dump
  - trying to make the scheduler kicks a little bit less frequent
  - if the compiler is supposed to keep temp files, then we
    have to do it locally
* Tue Sep 12 2006 coolo@suse.de
- 0.7.13:
  - use file -L to follow symlinks in create-env
  - fix an easy valgrind error
  - make handling of the return values consistent
  - if the client is in WAITCOMPILE then it's waiting for some
    other host to compile, not this one. So job == 0 -> crash
  - fix crash if the scheduler goes away while daemon transfers
    environment
  - apparently sometimes gcc can hang forever in some
    cases. By the time the client disconects, we know
    we don't have to wait any longer, because there is
    nobody left caring about the result.
  - update node name each time we login to the scheduler.
    Fixes tons of "linux" hosts appearing in the icecream
    monitor
* Wed Sep  6 2006 coolo@suse.de
- 0.7.12:
  - fixing error handling when scheduler restarts
  - do not waitpid before we're sure we read all of g++'s
    output otherwise g++ waits for us to read and we're
    waiting for g++ to finish -> deadlock
* Tue Sep  5 2006 coolo@suse.de
- 0.7.11:
  - fix a crash in the daemon when the scheduler was gone while
    local jobs were waiting for finishing
  - separate stat handling from ping handling
    to avoid excessive stat/ping loops
    (increases internal version number)
  - only reset scheduler ping time if the scheduler ping'ed us
  - even when we can't determine native environment, we
    can still use the daemon for inter-process locking
    instead of falling back to file locking.
  - quicker reap of dead daemons
  - improved load guessing
  - fix stupid logic bug in ping tracking
* Mon Sep  4 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep  4 2006 coolo@suse.de
- 0.7.10:
  - handle errors in installing environments correctly
  - block daemons that have full discs
  - add -pipe to the command line to reduce disk usage
  - fix cancelling of jobs awaiting a remote job (were hanging
    in scheduler forever)
  - if ICECC=no is set, don't try to be clever
  - adding two more flags for local compilation (profile
    feedback related)
  - flush debug files before every fork to avoid dups in
    log output
  - be stricter in what messages are required to keep the
    daemon<->scheduler communication intact (network drops
    again)
* Sun Sep  3 2006 coolo@suse.de
- 0.7.9:
  - scheduler will ping the daemon periodically,
    daemon will disconnect if not pinged from time
    to time (to avoid network drops being unnoticed)
  - removed some debug output
  - make logging more consistent
  - increased internal protocol version (still compatible)
  - try even harder to avoid races in daemon
  - rework how clients are catched
  - some random cleanup
  - remove the "this should be an exception" output to
    avoid failing configure checks for nothing
  - make sure the assembler is dead before we cleanup object
    files
-Sat Sep  2 19:01:02 CEST 2006 - ro@suse.de
- 0.7.8:
  - fd leak fix, which caused a deadlock under
    certain conditions
  - rework some FreeBSD patches that caused problems
  - fix race between select and SIGCHILD
* Tue Aug 29 2006 coolo@suse.de
- reverted part of the FreeBSD patch that broke x86_64 envs
* Fri Aug 25 2006 coolo@suse.de
- 0.7.7:
  - clear all internal maps
  - patches by Frerich to support FreeBSD
  - avoid busy loop in bizarre conditions
  - found another case of endless hanging jobs
  - some process fixes
* Wed Aug 23 2006 schwab@suse.de
- Avoid race condition with slow scheduler.
* Thu Jul 13 2006 coolo@suse.de
- 0.7.6:
  - report all daemon error message to the client
  - fix support for biarch machines that have only one
    environment installed with another environment with
    the same name and different architecture being around
  - work-around a bug in older libstdc++
  - ensure nobody uses -u root
* Wed Jul 12 2006 coolo@suse.de
- 0.7.5:
  - Don't block while looking for a scheduler over broadcast search.
  - Fix logrotate
  - immediately kick broken daemon connections
* Sat Jul  8 2006 coolo@suse.de
  0.7.4:
  - Add -fpreprocessed argument
  - Fix daemons getting stuck after a while with 100%% CPU
  - fix for kubuntu where libs are deeply nested
    such as /lib/tls/i686/cmov/libc.so.6
  - find the compiler even though icecc wasn't in the path
  - fix deletion of old environments
  - a lot more error handling
  - fix assertion failures in daemon upon sigchild delivery
  - use -fPIC also for C files
  - avoid race between local and remote daemon about who has
    the right exit status
  - rename the package to icecc
* Wed Jun 21 2006 coolo@suse.de
- fix build on 64 bit archs and older kernels
* Tue Jun 20 2006 coolo@suse.de
  0.7.3:
  - more work on error handling
  - corrected icecc --help output
  - handle local icecream load correctly
  - reduce the number of load updates from daemon to scheduler
  - early launch the compiler even before the whole preprocessed
    file has been received
  - handle low-latency networks better
  - builtin colorgcc
  - let the daemon schedule local load even without scheduler (important
    for multi processor machines)
* Mon Jun 12 2006 coolo@suse.de
- fix x86_64 build
* Fri Jun  9 2006 coolo@suse.de
  0.7.2:
  - split out libicecream-devel for the monitor
  - introducing ICECC_PREFERRED_HOST (=mybigfathost) to let
    the scheduler ignore all rules - this is meant to be a
    debugging aid
  - fix network performance between client and local daemon
  - replaced create-env with icecc --build-native (respecting
    the user's $PATH by default)
* Fri Jun  2 2006 mls@suse.de
  0.7.1:
  - Monitor is an extra package now
  - don't make non-existant cross compilers fatal, but just use
    the other environments in ICECC_VERSION
  - always handle aborted syscalls
  - update minilzo
  - never exit() or return from fork()'ed code paths,
* Thu Jun  1 2006 coolo@suse.de
  0.7.0:
  - WARNING: the protocol is not compatible with earlier
  versions, old clients will refuse to connect, so update
  the full farm
  - protocol reworked to no longer require a client->scheduler
  connection (the daemon will proxy it all)
  - all local jobs are now scheduled by the local daemon to
  make sure multiprocessor machines are handling as many jobs
  as they have jobs configured (# processors). They used to
    be "scheduled" by lock file
  - fixed grave bug that removed all daemon environments when
  the cache grew over limit
  - new telnet interface command: internals to output daemon
    states
  - stricter error handling to avoid suprises
  - SIGHUP to daemon and scheduler will reopen the log file
    to allow logrotate
  - a restart of the daemon and scheduler won't flush the log
    file, but append to it
  - create-env will create .tar.gz now - the client allows
    environments to be .tar, .tar.bz2 and .tar.gz
* Fri May 19 2006 coolo@suse.de
- update from SVN to adapt to the new location
- some fixes for catching out of memory situations better
- package man pages
* Fri Mar  3 2006 stbinner@suse.de
- make sure that log file exists and is writeable by icecream user
  (#141534)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 coolo@suse.de
- 0.6.3: make sure the daemon does not erase environments too often
  (no client change)
* Fri Jan 13 2006 coolo@suse.de
- update to 0.6.2
* Mon Dec 19 2005 coolo@suse.de
- remove links
* Thu Oct 13 2005 coolo@suse.de
- update tarball to fix with gcc 4.1
* Fri Sep  2 2005 schwab@suse.de
- Require gcc-c++.
* Wed Apr 13 2005 coolo@suse.de
- some changes to the daemon to keep the cache size below 100MB
* Wed Apr 13 2005 coolo@suse.de
- update tarball
* Mon Feb 21 2005 schwab@suse.de
- create-env: try to find generic versions of libraries.  Remove
  LD_ASSUME_KERNEL hack.
* Sat Feb  5 2005 schwab@suse.de
- Don't set LD_ASSUME_KERNEL in BETA.
* Fri Jan 21 2005 coolo@suse.de
- some fixes from CVS
* Mon Jan 17 2005 schwab@suse.de
- create-env: Add specs only if it exists as file.
* Wed Nov 17 2004 coolo@suse.de
- fixing dead loop
* Sun Nov 14 2004 schwab@suse.de
- Don't use icecc during build.
* Tue Nov  2 2004 coolo@suse.de
- ignore duplicated platforms to avoid confusion between native
  compiler and cross compiler
* Wed Oct 13 2004 coolo@suse.de
- several improvements in the communication layer
- the daemon kills compiler jobs when the client exists before
  awaiting the result (gcc4 feature :)
* Tue Sep 28 2004 od@suse.de
- in create-env, use LD_ASSUME_KERNEL=2.4.21 on ppc64
* Fri Sep 10 2004 schwab@suse.de
- Workaround cfg bug in gcc.
* Mon Sep  6 2004 coolo@suse.de
- handle being called without _any_ environment variables correctly
  (blender's use of scons)
* Mon Sep  6 2004 coolo@suse.de
- correctly calculating output filename for -S jobs (grub's configure)
* Sun Sep  5 2004 coolo@suse.de
- several improvements in the network code to make things more
  robust on general network slowness
- speed up configure runs
* Tue Aug 31 2004 coolo@suse.de
- do calculate the load a bit more fair for those machines that got
  other niced jobs
- add time information to the log output
- track a bit more carefully the child pids
* Mon Aug 30 2004 coolo@suse.de
- do not crash when the network goes down (again)
- some cleanup
* Sun Aug 29 2004 coolo@suse.de
- finding quite some scheduler troubles while watching a network
  with half the computers using WLAN (KDE conference)
- run everything the daemon does with client data as specific user
- changed the spec file to create that user and move the cache
  dir to /var/cache/icecream
- more options for the sysconfig
* Wed Aug 18 2004 coolo@suse.de
- avoid crashes when the connection between client and daemon
  goes down (as happend at night)
* Tue Aug 17 2004 coolo@suse.de
- fix handling of unknown paramters (failed/gsl)
* Sun Aug 15 2004 coolo@suse.de
- bugfixes and more flag statistics
* Thu Aug 12 2004 coolo@suse.de
- transfer debug and optimization flags to the scheduler for better
  speed calculation
* Thu Aug 12 2004 coolo@suse.de
- fixing ugly regression in the daemon. Increased protocol version
  to avoid problems with these old daemons
* Wed Aug 11 2004 coolo@suse.de
- Fixing grave performance problem and several scheduler crashes
* Wed Aug  4 2004 coolo@suse.de
- update for new automake, let the daemon set a ulimit for memory usage
* Fri Jul 30 2004 coolo@suse.de
- don't stress the scheduler while compiling jobs three times
- also use icecream for .c files
- fix for the init script
* Tue Jun 29 2004 coolo@suse.de
- fixing bugs reported by prague office and ro
* Fri Jun 11 2004 coolo@suse.de
- major update (including fix for gcc build)
* Tue May 11 2004 coolo@suse.de
- really fixing build with several input files
* Tue May  4 2004 coolo@suse.de
- fix build with several input files (ltp package)
* Mon May  3 2004 coolo@suse.de
- support cross compiling
* Wed Apr 28 2004 coolo@suse.de
- support multiple architectures in the scheduler
* Mon Apr 26 2004 coolo@suse.de
- filter out more errors as info message trying to get binutils's
  testsuite to work
* Sun Apr 25 2004 coolo@suse.de
- adding -frandom-seed to the compilation for the jobs that compile
  thee times on several hosts
* Fri Apr 23 2004 coolo@suse.de
- fixing grave bug in the setup of the protocol version which caused
  lookups
* Thu Apr 22 2004 coolo@suse.de
- several fixes in the transport layer and the client now compiles
  every 5th job three times to test the farm
* Sat Apr 17 2004 coolo@suse.de
- splitting monitor into an extra source to simplify build
  requirements for the client
* Fri Apr 16 2004 coolo@suse.de
- new protocol version for fancier monitors
* Fri Apr 16 2004 coolo@suse.de
- new version with revised monitor and new init script name
* Tue Apr 13 2004 coolo@suse.de
- initial package
